@@ -12,7 +12,7 @@
 #endif
 
 #ifndef BUILD_GLES2
-/* #undef BUILD_GLES2 */
+#define BUILD_GLES2
 #endif
 
 // Miscellaneous flags
@@ -95,10 +95,6 @@
 #define USE_LZMA
 #endif
 
-#ifndef USE_MAGICK
-#define USE_MAGICK
-#endif
-
 #ifndef USE_MINIZIP
 /* #undef USE_MINIZIP */
 #endif
